@@ -196,6 +196,7 @@ static constexpr const KeyCategoryMapEntry simple_key_map[] = {
     M("cuisine", Cuisine, Main),
     M("description", Description, Main),
     M("diaper", DiaperChangingTable, UnresolvedCategory),
+    M("diplomatic", Category, Header),
     M("email", Email, Contact),
     M("fee", Fee, UnresolvedCategory),
     M("genus", Name, Header),
@@ -207,6 +208,7 @@ static constexpr const KeyCategoryMapEntry simple_key_map[] = {
     M("mx:remaining_range", RemainingRange, Main),
     M("mx:vehicle", Category, Header),
     M("network", Network, Operator),
+    M("network:wikipedia", OperatorWikipedia, Operator),
     M("office", Category, Header),
     M("old_name", OldName, UnresolvedCategory),
     M("opening_hours", OpeningHours, OpeningHoursCategory),
@@ -561,7 +563,11 @@ QVariant OSMElementInformationModel::valueForKey(Info info) const
             appendNonEmpty(m_element.tagValue("shop"), l);
             appendNonEmpty(m_element.tagValue("tourism"), l);
             appendNonEmpty(m_element.tagValue("vending"), l);
-            appendNonEmpty(m_element.tagValue("office"), l);
+            const auto diplomatic = m_element.tagValue("diplomatic");
+            appendNonEmpty(diplomatic, l);
+            if (diplomatic.isEmpty()) {
+                appendNonEmpty(m_element.tagValue("office"), l);
+            }
             appendNonEmpty(m_element.tagValue("leisure"), l);
             appendNonEmpty(m_element.tagValue("historic"), l);
             appendNonEmpty(m_element.tagValue("mx:vehicle"), l);
@@ -819,7 +825,7 @@ QVariant OSMElementInformationModel::valueForKey(Info info) const
         }
         case OperatorName: return QString::fromUtf8(m_element.tagValue("operator"));
         case Network: return QString::fromUtf8(m_element.tagValue("network"));
-        case OperatorWikipedia: return wikipediaUrl(m_element.tagValue(QLocale(), "operator:wikipedia"));
+        case OperatorWikipedia: return wikipediaUrl(m_element.tagValue(QLocale(), "operator:wikipedia", "network:wikipedia"));
         case RemainingRange:
         {
             const auto range = m_element.tagValue("mx:remaining_range").toInt();
